@@ -22,6 +22,8 @@ import warnings
 import PyPDF2
 from io import StringIO
 
+tables = ""
+
 pick_table = '''
 
 >>  Select preferred table output below.
@@ -94,7 +96,11 @@ title = '''
 
 '''
 
+text_p = '''
 
+>>  Enter path to output text file (must be .txt): 
+
+'''
 def wait():
         print("\nPress [ENTER] to start Alacorder or [CTRL-C] to quit...\n")
         a = input()
@@ -118,7 +124,15 @@ def pickTable():
                 tables = "cases"
         return tables
 
-
+def splitext(path: str):
+    head = os.path.split(path)[0]
+    tail = os.path.split(path)[1]
+    ext = os.path.splitext(path)[1] 
+    return pd.Series({
+        'head': head,
+        'tail': tail,
+        'ext': ext
+        })
 
 warnings.filterwarnings("ignore")
 
@@ -132,15 +146,38 @@ archive_path = ""
 
 input_path = "".join(input())
 incheck = alac.checkPath(input_path)
+inext = splitext(input_path)['ext']
+
+if inext == ".pdf":
+        text = alac.getPDFText(input_path)
+        print(text_p)
+        path = "".join(input())
+        with open(path, 'w') as f:
+                f.write(text)
+        print("Exported full text to .txt")
+        incheck = "NO"
+
+if inext == ".txt":
+        with open(input_path) as f:
+                text = f.readlines()
+        print(text_p)
+        path = "".join(input())
+        tp = alac.checkPath(path)
+        with open(path, 'w') as f:
+                f.write(text)
+        print("Exported full text to .txt")
+        incheck = "NO"
 
 if incheck == "existing_archive":
         print(just_table)
         table_path = "".join(input())
         tp = alac.checkPath(table_path)
         if tp == "table":
-                tables = pickTable()
+                if tables == "":
+                        tables = pickTable()
         elif tp == "overwrite_table":
-                tables = pickTable()
+                if tables == "":
+                        tables = pickTable()
         elif tp == "overwrite_all_tables":
                 tables = "all_tables"
         elif tp == "all_tables":
@@ -170,14 +207,16 @@ if incheck == "pdf_directory":
                 makeArchive = False
                 table_path = next_path
                 makeTable = True
-                tables = pickTable()
+                if tables == "":
+                        tables = pickTable()
                 a = alac.config(input_path, table_path=table_path, tables=tables)
                 alac.parseTables(a)
         if np == "table":
                 makeArchive = False
                 makeTable = True
                 table_path = next_path
-                tables = pickTable()
+                if tables == "":
+                        tables = pickTable()
                 a = alac.config(input_path, table_path=table_path, tables=tables)
                 alac.parseTables(a)
         if np == "all_tables":
@@ -229,11 +268,19 @@ if incheck == "pdf_directory":
         if makeTable or makeAllTables:
                 if makeArchive:
                         input_path = archive_path
-                if makeTable:
+                if makeTable and tables == "":
                         tables = pickTable()
+                elif makeTable:
+                        pass
                 else:
                         tables = "all_tables"
                 a = alac.config(input_path, table_path=table_path, tables=tables, GUI_mode = True)
                 alac.parseTables(a, tables)
 
 
+
+
+
+
+
+
